%define set_tcbver 0.7

%define major   0
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d
%define libpamname %mklibname pam 0

Summary:        Libraries and tools implementing the tcb password shadowing scheme
Name:           tcb
Version:        1.2
Release:        %mkrel 5
License:        BSD or GPL+
Group:          System/Libraries
URL:            https://www.openwall.com/tcb/
Source0:        https://www.openwall.com/tcb/%{name}-%{version}.tar.gz
Source1:        https://www.openwall.com/tcb/%{name}-%{version}.tar.gz.sign
Source2:        set_tcb-%{set_tcbver}.tar.bz2
Patch0:         tcb-1.0.2-assume_shadow.patch
Patch1:		tcb-1.1-libtirpc.patch
Patch2:         set_tcb-0.7-nofork.patch
# Fix handling of negative fields in /etc/shadow on x86_64 with recent glibc (#52330)
Patch3:         tcb-1.0.3-warn.patch

BuildRequires:  pkgconfig(libcrypt) >= 4.1.1-2
BuildRequires:  pkgconfig(libnsl)
BuildRequires:  pkgconfig(libtirpc)
BuildRequires:  pam-devel
Requires:       %{libname} >= %{version}
Requires:       pam_tcb = %{version}
Requires:       nss_tcb = %{version}
Requires:       shadow-utils >= 4.0.12-10


%description
The tcb package consists of three components: pam_tcb, libnss_tcb, and
libtcb.  pam_tcb is a PAM module which supersedes pam_unix and pam_pwdb.
It also implements the tcb password shadowing scheme (see tcb(5) for
details).  The tcb scheme allows many core system utilities (passwd(1)
being the primary example) to operate with little privilege.  libnss_tcb
is the accompanying NSS module.  libtcb contains code shared by the
PAM and NSS modules and is also used by programs from the shadow-utils
package.


%package -n %{libname}
Summary:        Libraries and tools implementing the tcb password shadowing scheme
Group:          System/Libraries
Requires:       %{_lib}xcrypt1 >= 4.1.1-2
Requires(pre):  setup 

%description -n %{libname}
libtcb contains code shared by the PAM and NSS modules and is also used
by programs from the shadow-utils package.


%package -n pam_tcb
Summary:        PAM module for TCB
Group:          System/Libraries
Requires:       %{libname} >= %{version}

%description -n pam_tcb
pam_tcb is a PAM module which supersedes pam_unix and pam_pwdb.
It also implements the tcb password shadowing scheme (see tcb(5) for
details).  The tcb scheme allows many core system utilities (passwd(1)
being the primary example) to operate with little privilege.


%package -n nss_tcb
Summary:        NSS library for TCB
Group:          System/Libraries
Requires(post): rpm-helper
Requires(postun): rpm-helper
Requires:       %{libname} = %{version}

%description -n nss_tcb
libnss_tcb is the accompanying NSS module for pam_tcb.


%package -n %{develname}
Summary:        Libraries and header files for building tcb-aware applications
Group:          Development/Other
Requires:       %{libname} >= %{version}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains static libraries and header files needed for
building tcb-aware applications.

%prep
%setup -q -a2
%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p0
%patch -P 3 -p1

cat Make.defs | sed -e "s|LIBEXECDIR = /usr/libexec|LIBEXECDIR = %{_libdir}|" >Make.defs.new
cat Make.defs.new | sed -e "s|/lib$|/%{_lib}|g" >Make.defs
# Fix upstream perm bug #3053
chmod 644 LICENSE

%build
%serverbuild
CFLAGS="%{optflags} -DENABLE_SETFSUGID -I/usr/include/tirpc" %make_build

%install
make install-non-root install-pam_pwdb \
    DESTDIR=%{buildroot} \
    MANDIR=%{_mandir} \
    LIBDIR=%{_libdir} \
    LIBEXECDIR=%{_libdir} \
    SLIBDIR=/%{_lib}

mkdir -p %{buildroot}%{_sbindir}
install -m 0750 set_tcb-%{set_tcbver}/set_tcb %{buildroot}%{_sbindir}/
install -m 0644 set_tcb-%{set_tcbver}/set_tcb.8 %{buildroot}%{_mandir}/man8/

%post -n nss_tcb
if [ -f %{_initrddir}/nscd ]; then
    %_post_service nscd
fi

%postun -n nss_tcb
if [ -f %{_initrddir}/nscd ]; then
    %_preun_service nscd
fi

%files
%doc LICENSE
/sbin/tcb_convert
/sbin/tcb_unconvert
%{_sbindir}/set_tcb
%{_mandir}/man8/tcb_convert.8*
%{_mandir}/man8/tcb_unconvert.8*
%{_mandir}/man8/set_tcb.8*

%files -n %{libname}
/%{_lib}/libtcb.so.%{major}*
%attr(0755,root,chkpwd) %verify(not mode group) %dir %{_libdir}/chkpwd
%attr(2755,root,shadow) %verify(not mode group) %{_libdir}/chkpwd/tcb_chkpwd
%{_mandir}/man5/tcb.5*

%files -n nss_tcb
/%{_lib}/libnss_tcb.so.2

%files -n pam_tcb
/%{_lib}/security/pam_pwdb.so
/%{_lib}/security/pam_tcb.so
%{_mandir}/man8/pam_pwdb.8*
%{_mandir}/man8/pam_tcb.8*

%files -n %{develname}
%{_includedir}/tcb.h
%{_libdir}/libtcb.a
%{_libdir}/libtcb.so


%changelog
* Mon Jun 30 2025 umeabot <umeabot> 1.2-5.mga10
+ Revision: 2232471
- Mageia 10 Mass Rebuild

* Sun Dec 22 2024 pterjan <pterjan> 1.2-4.mga10
+ Revision: 2128195
- Rebuild for patchN deprecation

* Fri Apr 05 2024 wally <wally> 1.2-3.mga10
+ Revision: 2054688
- basesystem rebuild for i686

* Sun Mar 27 2022 umeabot <umeabot> 1.2-2.mga9
+ Revision: 1829263
- Mageia 9 Mass Rebuild

* Sun Aug 08 2021 luigiwalser <luigiwalser> 1.2-1.mga9
+ Revision: 1740473
- 1.2
- rediff patch 1
- remove patch 4 (fixed upstream)

* Thu Dec 17 2020 tv <tv> 1.1-12.mga8
+ Revision: 1660456
- BR pkgconfig(libnsl)

* Mon Dec 07 2020 luigiwalser <luigiwalser> 1.1-11.mga8
+ Revision: 1654141
- try to fix libtirpc build
- try building with libtirpc

* Fri Feb 14 2020 umeabot <umeabot> 1.1-10.mga8
+ Revision: 1517390
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 1.1-9.mga7
+ Revision: 1301334
- Mageia 7 Mass Rebuild

* Wed Aug 08 2018 tmb <tmb> 1.1-8.mga7
+ Revision: 1250269
- switch to libxcrypt

* Fri Feb 12 2016 umeabot <umeabot> 1.1-7.mga6
+ Revision: 958978
- Mageia 6 Mass Rebuild

* Fri Aug 21 2015 tmb <tmb> 1.1-6.mga6
+ Revision: 867743
- rebuild for new gcc

* Wed Oct 15 2014 umeabot <umeabot> 1.1-5.mga5
+ Revision: 745667
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.1-4.mga5
+ Revision: 689732
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 1.1-3.mga4
+ Revision: 519567
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 1.1-2.mga3
+ Revision: 384136
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Mar 03 2012 fwang <fwang> 1.1-1.mga2
+ Revision: 217158
- new version 1.1

* Mon Dec 05 2011 barjac <barjac> 1.0.6-1.mga2
+ Revision: 177111
- Fix perm on LICENSE and general cleanup

* Tue Jan 11 2011 pterjan <pterjan> 1.0.6-0.mga1
+ Revision: 5882
- Drop old stuff
- imported package tcb


* Sun Dec 05 2010 Oden Eriksson <oeriksson@mandriva.com> 1.0.6-0mdv2011.0
+ Revision: 609635
- 1.0.6
- drop P5, it's applied upstream
- spec file massage

* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 1.0.3-7mdv2011.0
+ Revision: 607982
- rebuild

* Fri Jun 04 2010 Pascal Terjan <pterjan@mandriva.org> 1.0.3-6mdv2010.1
+ Revision: 547106
- fix tcb_is_suspect (breaks at least on btrfs) (#59588)
- translate more strings

* Fri May 21 2010 Pascal Terjan <pterjan@mandriva.org> 1.0.3-4mdv2010.1
+ Revision: 545602
- Use translations from pam for available messages (#59331)

* Thu Dec 17 2009 Pascal Terjan <pterjan@mandriva.org> 1.0.3-3mdv2010.1
+ Revision: 479732
- Fix handling of negative fields in /etc/shadow on x86_64 with recent glibc (#52330)

* Thu Sep 03 2009 Christophe Fergeau <cfergeau@mandriva.com> 1.0.3-2mdv2010.0
+ Revision: 427284
- rebuild

* Thu Apr 09 2009 Oden Eriksson <oeriksson@mandriva.com> 1.0.3-1mdv2009.1
+ Revision: 365388
- 1.0.3
- drop the exit patch, it's implemented upstream (P1)

* Tue Mar 31 2009 Pascal Terjan <pterjan@mandriva.org> 1.0.2-21mdv2009.1
+ Revision: 362887
- Do not set fork option

* Mon Mar 30 2009 Pascal Terjan <pterjan@mandriva.org> 1.0.2-20mdv2009.1
+ Revision: 362228
- Don't call atexit signals in child process (#43106)

* Thu Dec 18 2008 Vincent Danen <vdanen@mandriva.com> 1.0.2-19mdv2009.1
+ Revision: 315404
- set_tcb 0.7; should fix some issues with changing password hashes

* Wed Aug 27 2008 Vincent Danen <vdanen@mandriva.com> 1.0.2-18mdv2009.0
+ Revision: 276450
- set_tcb 0.6

* Mon Aug 25 2008 Vincent Danen <vdanen@mandriva.com> 1.0.2-17mdv2009.0
+ Revision: 275953
- relax permissions of the password checker

* Tue Aug 12 2008 Vincent Danen <vdanen@mandriva.com> 1.0.2-16mdv2009.0
+ Revision: 271142
- remove the %%trigger script, due to install ordering it will never be run so put it in the pam package instead

* Sun Aug 10 2008 Olivier Blin <oblin@mandriva.com> 1.0.2-15mdv2009.0
+ Revision: 270204
- conflict with pam and libpam0 < 0.99.8.1-13
  (or else we can end up with no pam_unix on the system)

* Sat Aug 09 2008 Vincent Danen <vdanen@mandriva.com> 1.0.2-14mdv2009.0
+ Revision: 270080
- set_tcb 0.5
  don't install pam_unix compat symlinks
  call set_tcb to migrate login.defs and system-auth

* Fri Aug 08 2008 Vincent Danen <vdanen@mandriva.com> 1.0.2-13mdv2009.0
+ Revision: 269005
- set_tcb 0.3

* Sat Jul 19 2008 Vincent Danen <vdanen@mandriva.com> 1.0.2-12mdv2009.0
+ Revision: 238837
- set_tcb 0.2

* Mon Jul 14 2008 Vincent Danen <vdanen@mandriva.com> 1.0.2-11mdv2009.0
+ Revision: 234436
- include the set_tcb script

* Sat Jun 14 2008 Vincent Danen <vdanen@mandriva.com> 1.0.2-10mdv2009.0
+ Revision: 219107
- really fix the nscd restart

* Wed Jun 11 2008 Vincent Danen <vdanen@mandriva.com> 1.0.2-9mdv2009.0
+ Revision: 218049
- make the nscd test exit 0 if the nscd initscript doesn't exist

* Mon Jun 09 2008 Vincent Danen <vdanen@mandriva.com> 1.0.2-8mdv2009.0
+ Revision: 217264
- make sure the nscd initscript exists before trying to restart it

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Sat May 31 2008 Frederik Himpe <fhimpe@mandriva.org> 1.0.2-7mdv2009.0
+ Revision: 213851
- Fix conflicts to make it upgrade without conflicts from 2008.1

* Fri May 30 2008 Vincent Danen <vdanen@mandriva.com> 1.0.2-6mdv2009.0
+ Revision: 213352
- make /usr/lib/chkpwd world-executable so gnome-screensaver will work (as we cannot make it sgid chkpwd)

* Fri May 23 2008 Vincent Danen <vdanen@mandriva.com> 1.0.2-5mdv2009.0
+ Revision: 210386
- further make fixes

* Fri May 23 2008 Vincent Danen <vdanen@mandriva.com> 1.0.2-4mdv2009.0
+ Revision: 210180
- fix where pam_tcb is finding it's password helper

* Wed May 21 2008 Vincent Danen <vdanen@mandriva.com> 1.0.2-3mdv2009.0
+ Revision: 209784
- added assume_shadow.patch: pam_unix assumes that 'shadow' is set always,
  but pam_tcb only assumes this for account, so add it to the other pam types

* Mon May 19 2008 Vincent Danen <vdanen@mandriva.com> 1.0.2-2mdv2009.0
+ Revision: 209102
- add conflicts on old pre-TCB-aware pam
- requires TCB-aware shadow-utils

* Sun May 18 2008 Vincent Danen <vdanen@mandriva.com> 1.0.2-1mdv2009.0
+ Revision: 208802
- fix group on the -devel package
- import tcb from Annvix


